# Python
__pycache__
*.pyc
*.pyo
*.pyd
.Python
*.so
*.egg
*.egg-info
dist
build

# Virtual environments
.venv
venv
ENV

# Git
.git
.gitignore
.gitattributes

# IDE
.vscode
.idea
*.swp
*.swo

# Testing
.pytest_cache
.coverage
htmlcov
.tox
.nox

# Documentation
docs/
*.md
!README.md

# CI/CD
.github
.gitlab-ci.yml

# Environment
.env
.env.*
!.env.example

# Logs
*.log
logs/

# Data
data/
*.sqlite
*.db