"""
MCP Builder - Production-grade MCP server project generator.

A comprehensive CLI tool for scaffolding Model Context Protocol servers
with enterprise-level best practices, modern tooling, and extensive customization options.
"""

__version__ = "0.1.0"
__author__ = "Kapil Dagur"
__email__ = "kapildagur1306@gmail.com"
__license__ = "MIT"
__url__ = "https://github.com/KapilDagur/mcp-builder"

__all__ = [
    "__version__",
    "__author__",
    "__email__",
    "__license__",
    "__url__",
]