{
  "recommendations": [
    "ms-python.python",
    "ms-python.vscode-pylance",
    "charliermarsh.ruff",
    "tamasfe.even-better-toml",
    "redhat.vscode-yaml",
{% if include_docker %}
    "ms-azuretools.vscode-docker",
{% endif %}
    "github.vscode-github-actions",
    "usernamehw.errorlens",
    "eamodio.gitlens",
    "streetsidesoftware.code-spell-checker"
  ]
}